StorageError

Enum StorageError 

#[non_exhaustive]
pub enum StorageError { DuplicateTable { name: String, }, TableNotFound { name: String, }, ArityMismatch { expected: usize, actual: usize, }, TypeMismatch { column: String, expected: DataType, actual: DataType, position: usize, }, NullInNotNull { column: String, }, DuplicateIndex { name: String, }, ColumnNotFound { column: String, }, Corrupt(String), IndexNotFound { name: String, }, Unsupported(String), }

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


DuplicateTable

Fields

name: String


TableNotFound

Fields

name: String


ArityMismatch

Fields

expected: usize
actual: usize


TypeMismatch

Fields

column: String
expected: DataType
actual: DataType
position: usize


NullInNotNull

Fields

column: String


DuplicateIndex

Index with this name already exists on the table.

Fields

name: String


ColumnNotFound

Column referenced by an index doesn’t exist on the table.

Fields

column: String


Corrupt(String)

On-disk format failed to parse — corrupted file, wrong magic, truncated payload, or unknown tag bytes.



IndexNotFound

v6.0.4 — ALTER INDEX targeted an index name that doesn’t exist on any table in this catalog.

Fields

name: String


Unsupported(String)

v6.0.4 — operation requested isn’t supported on this index kind / column type (e.g. ALTER INDEX REBUILD on a BTree index, or REBUILD WITH (encoding=…) on a non-vector column).